@@ -1263,7 +1263,10 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
           /* add the menu items to the menu */
           for (lp = items; lp != NULL; lp = lp->next)
-            thunar_gtk_menu_thunarx_menu_item_new (lp->data, GTK_MENU_SHELL (menu));
+            {
+              item = thunar_gtk_menu_thunarx_menu_item_new (lp->data, GTK_MENU_SHELL (menu));
+              gtk_widget_show (item);
+            }
 
           /* cleanup */
           g_list_free (items);
